import sys
import uasyncio
import machine
import uasyncio as asyncio
from machine import Pin, PWM

led_r = PWM(Pin(22), 5000)
led_g = PWM(Pin(26), 5000)
led_b = PWM(Pin(27), 5000)

rgb_pwr = 0.1 # 0.0 - 1.0


async def init():
    led_r.duty_u16(0)
    led_g.duty_u16(0)
    led_b.duty_u16(0)

async def set_pwr(pwr):
    global rgb_pwr
    rgb_pwr = pwr   


async def set(r, g, b):
    led_r.duty_u16(int(65535 * r * rgb_pwr))
    led_g.duty_u16(int(65535 * g * rgb_pwr))
    led_b.duty_u16(int(65535 * b * rgb_pwr))
    await uasyncio.sleep(0.01)



async def on():
    led_r.duty_u16(65535 * rgb_pwr)    # 65535 = on
    led_b.duty_u16(65535 * rgb_pwr)    # 65535 = on
    led_g.duty_u16(65535 * rgb_pwr)    # 65535 = on

async def off():
    led_r.duty_u16(0)    # 0 = off
    led_g.duty_u16(0)    # 0 = off 
    led_b.duty_u16(0)    # 0 = off

async def test():
    print("RGB demo")
    print("Press Ctrl-C to exit")
    await uasyncio.sleep(1)
    print("RGB power:", rgb_pwr)
    print("RGB initializing...")
    await init()
    await uasyncio.sleep(1)
    while True:
        print("RGB off")
        await set(0, 0, 0)
        await uasyncio.sleep(1)
        print("Red on")
        await set(1, 0, 0)
        await uasyncio.sleep(1)
        print("Green on")
        await set(0, 1, 0)
        await uasyncio.sleep(1)
        print("Blue on")
        await set(0, 0, 1)
        await uasyncio.sleep(1)
        print("RGB on")
        await set(1, 1, 1)
        await uasyncio.sleep(1)
    
asyncio.run(test())


 

